@@ -37,7 +37,7 @@ class NfsaasProvider(object):
         LOG.info("Export created: %s" % export)
         
         LOG.info("Creating access!")
-        access = nfsaas.create_access(environmentid=nfsaas_environmentid, sizeid=nfsaas_planid, exportid=export['id'], host=host.hostname)
+        access = nfsaas.create_access(environmentid=nfsaas_environmentid, sizeid=nfsaas_planid, exportid=export['id'], host=host.address)
         LOG.info("Access created: %s" % access)
         
         LOG.info("Saving export info on nfsaas host attr")
